@@ -64,68 +64,99 @@ class TestLoss(unittest.TestCase):
 
 class TestEval(unittest.TestCase):
     def testEMF1(self):
-        eval = tfkit.utility.eval_metric.EvalMetric()
+        tokenizer = BertTokenizer.from_pretrained('voidful/albert_chinese_tiny')
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval.add_record("input", "abc", "abb[SEP]acc[SEP]abc", task='default')
         for s in eval.cal_score('emf1'):
             print(s)
             self.assertTrue(s[1]['EM'] == 1)
             self.assertTrue(s[1]['F1'] == 1)
 
-        eval = tfkit.utility.eval_metric.EvalMetric()
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval.add_record("input", "ab", "abb[SEP]acc[SEP]ab c", task='default')
         for s in eval.cal_score('emf1'):
             print(s)
             self.assertTrue(s[1]['EM'] == 0)
             self.assertTrue(s[1]['F1'] > 0)
 
-        eval = tfkit.utility.eval_metric.EvalMetric()
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval.add_record("input", "a b c", "a b b[SEP]a c c[SEP]", task='default')
         for s in eval.cal_score('emf1'):
             print(s)
             self.assertTrue(s[1]['EM'] == 0)
             self.assertTrue(s[1]['F1'] > 0)
 
-        eval = tfkit.utility.eval_metric.EvalMetric()
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval.add_record("input", "", "a b b[SEP]a c c[SEP]", task='default')
         for s in eval.cal_score('emf1'):
             print(s)
             self.assertTrue(s[1]['EM'] == 0)
             self.assertTrue(s[1]['F1'] == 0)
 
-    def testNLG(self):
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
+        eval.add_record("input", "a", ["a"], task='default')
+        for s in eval.cal_score('emf1'):
+            print(s)
+            self.assertTrue(s[1]['EM'] == 1)
+            self.assertTrue(s[1]['F1'] == 1)
 
-        eval = tfkit.utility.eval_metric.EvalMetric()
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
+        eval.add_record("input", "a", ["b"], task='default')
+        for s in eval.cal_score('emf1'):
+            print(s)
+            self.assertTrue(s[1]['EM'] == 0)
+            self.assertTrue(s[1]['F1'] == 0)
+
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
+        eval.add_record("input", "b", ["a"], task='default')
+        for s in eval.cal_score('emf1'):
+            print(s)
+            self.assertTrue(s[1]['EM'] == 0)
+            self.assertTrue(s[1]['F1'] == 0)
+
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
+        eval.add_record("input", "b", ["b"], task='default')
+        for s in eval.cal_score('emf1'):
+            print(s)
+            self.assertTrue(s[1]['EM'] == 1)
+            self.assertTrue(s[1]['F1'] == 1)
+
+
+
+    def testNLG(self):
+        tokenizer = BertTokenizer.from_pretrained('voidful/albert_chinese_tiny')
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
         eval.add_record("input", "a b c", "a b c[SEP]a c c[SEP]", task='default')
         for s in eval.cal_score('nlg'):
             print(s)
 
-        eval1 = tfkit.utility.eval_metric.EvalMetric(max_candidate=1)
+        eval1 = tfkit.utility.eval_metric.EvalMetric(tokenizer,max_candidate=1)
         eval1.add_record("input", "abc", " abc ", task='default')
         for s1 in eval1.cal_score('nlg'):
             print(s1)
 
-        eval3 = tfkit.utility.eval_metric.EvalMetric(max_candidate=3)
+        eval3 = tfkit.utility.eval_metric.EvalMetric(tokenizer,max_candidate=3)
         eval3.add_record("input", "abc ", "abb [SEP]acc[SEP] abc ", task='default')
         for s3 in eval3.cal_score('nlg'):
             print(s3)
 
-        eval6 = tfkit.utility.eval_metric.EvalMetric(max_candidate=6)
+        eval6 = tfkit.utility.eval_metric.EvalMetric(tokenizer,max_candidate=6)
         eval6.add_record("input", "abc", "abb [SEP] acc [SEP]abc", task='default')
         for s6 in eval6.cal_score('nlg'):
             print(s6)
         self.assertTrue(s1 == s3 == s6)
 
-        eval1 = tfkit.utility.eval_metric.EvalMetric(max_candidate=1)
+        eval1 = tfkit.utility.eval_metric.EvalMetric(tokenizer,max_candidate=1)
         eval1.add_record("input", "opq", "abc", task='default')
         for s1 in eval1.cal_score('nlg'):
             print(s1)
 
-        eval3 = tfkit.utility.eval_metric.EvalMetric(max_candidate=3)
+        eval3 = tfkit.utility.eval_metric.EvalMetric(tokenizer,max_candidate=3)
         eval3.add_record("input", "opq", "abb[SEP]acc[SEP]abc", task='default')
         for s3 in eval3.cal_score('nlg'):
             print(s3)
 
-        eval6 = tfkit.utility.eval_metric.EvalMetric(max_candidate=6)
+        eval6 = tfkit.utility.eval_metric.EvalMetric(tokenizer,max_candidate=6)
         eval6.add_record("input", "opq", "abb [SEP] acc[SEP]abc", task='default')
         for s6 in eval6.cal_score('nlg'):
             print(s6)
@@ -138,3 +169,16 @@ class TestEval(unittest.TestCase):
         for s in eval.cal_score('classification'):
             print(s[0])
             print(s[1])
+
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
+        eval.add_record("input", "你 好", "我 好[SEP]你 好 嗎[SEP]好 嗎", task='default')
+        for s in eval.cal_score('classification'):
+            print(s[0])
+            print(s[1])
+
+        eval = tfkit.utility.eval_metric.EvalMetric(tokenizer)
+        eval.add_record("input", "1 3 2", "1 2 3", task='default')
+        eval.add_record("input", "1 3 2", "1 3 3", task='default')
+        for s in eval.cal_score('classification'):
+            print(s[0])
+            print(s[1])
