@@ -8,7 +8,10 @@ def _normalize_answer(s):
     """Lower text and remove punctuation, articles and extra whitespace."""
 
     def remove_articles(text):
-        return re.sub(r'\b(a|an|the)\b', ' ', text)
+        if len(text) > 1:
+            return re.sub(r'\b(a|an|the)\b', ' ', text)
+        else:
+            return text
 
     def white_space_fix(text):
         return ' '.join(text.split())
@@ -70,10 +73,9 @@ class EvalMetric:
         self.tasks[task]['input'].append(input)
         self.tasks[task]['predicted'].append(predicted)
         self.tasks[task]['predicteds'].append([predicted])
-        self.tasks[task]['predicted_list'].append(predicted.split(" ") if " " in predicted else [predicted])
         self.tasks[task]['target'].append(target)
         self.tasks[task]['targets'].append(targets)
-        self.tasks[task]['target_list'].append(target.split(" ") if " " in target else [target])
+
 
     def get_record(self, task='default'):
         return self.tasks[task]
@@ -90,7 +92,8 @@ class EvalMetric:
                     f1_list = [0]
                     for target in task['targets'][pos]:
                         equal = False
-                        if _normalize_answer(predict) == _normalize_answer(target) and len(predict) > 0:
+                        if _normalize_answer(predict) == _normalize_answer(target) and len(
+                                _normalize_answer(predict)) > 0:
                             equal = True
                         if equal:
                             em_list.append(1)
@@ -113,10 +116,10 @@ class EvalMetric:
             if "classification" in metric:
                 from sklearn.metrics import classification_report
                 from sklearn.preprocessing import MultiLabelBinarizer
-                target_key = [t.split(" ") if " " in t else [t] for t in self.target_list[task_name].keys()]
-                mlb = MultiLabelBinarizer().fit([k for k in target_key if len(k) > 0])
+                target_key = [t for t in self.target_list[task_name].keys() if len(t) > 0]
+                mlb = MultiLabelBinarizer().fit([target_key])
                 result = classification_report(
-                    mlb.transform(task['target_list']),
-                    mlb.transform(task['predicted_list']),
+                    mlb.transform(task['targets']),
+                    mlb.transform(task['predicteds']),
                     target_names=list(mlb.classes_))
             yield (task_name, result)
